@@ -1670,13 +1670,15 @@ static void suspend(void)
 {
 	int res;
 
-	if (!quiet_mode)
+	if (!quiet_mode) {
 		fprintf(stderr, _("Suspended. Trying resume. ")); fflush(stderr);
+	}
 	while ((res = snd_pcm_resume(handle)) == -EAGAIN)
 		sleep(1);	/* wait until suspend flag is released */
 	if (res < 0) {
-		if (!quiet_mode)
+		if (!quiet_mode) {
 			fprintf(stderr, _("Failed. Restarting stream. ")); fflush(stderr);
+		}
 		if ((res = snd_pcm_prepare(handle)) < 0) {
 			error(_("suspend: prepare error: %s"), snd_strerror(res));
 			prg_exit(EXIT_FAILURE);
@@ -2821,7 +2823,8 @@ static int read_header(int *loaded, int header_size)
 
 	/* don't be adventurous, get out if file size is smaller than
 	 * requested header size */
-	if (buf.st_size < header_size)
+	if ((buf.st_mode & S_IFMT) == S_IFREG &&
+	    buf.st_size < header_size)
 		return -1;
 
 	if (*loaded < header_size) {
